@@ -19,25 +19,25 @@ import enum
 
 class FileInfo:
     """
-    文件/文件夹信息\n
-    name: 名称\n
-    type: 类型\n
-    size: 大小(byte)\n
-    suffix: 后缀(最后一个"."符号之后的字符串，如果没有则为空字符串)\n
-    permission: 权限的数字表示\n
-    last_modified: 最后修改时间(秒)\n
-    last_read: 最后读取时间(秒)\n
-    owner: 拥有者名称\n
-    owner_id: 拥有者ID\n
-    group: 用户组名称\n
-    group_id: 用户组ID
+    文件/文件夹信息。\n
+    :ivar name: 名称
+    :ivar type: 类型
+    :ivar size: 大小(byte)
+    :ivar suffix: 后缀(最后一个"."符号之后的字符串，如果没有则为空字符串)
+    :ivar permission: 权限的数字表示
+    :ivar last_modified: 最后修改时间(秒)
+    :ivar last_read: 最后读取时间(秒)
+    :ivar owner: 拥有者名称
+    :ivar owner_id: 拥有者ID
+    :ivar group: 用户组名称
+    :ivar group_id: 用户组ID
     """
     class Type(enum.Enum):
         """
-        文件类型\n
-        FILE: 文件(包括有效的符号连接)\n
-        DIRECTORY: 文件夹\n
-        OTHER: 其他类型
+        文件类型。\n
+        :ivar FILE: 文件(包括有效的符号连接)
+        :ivar DIRECTORY: 文件夹
+        :ivar OTHER: 其他类型
         """
         OTHER = -1
         FILE = 0
@@ -57,9 +57,11 @@ class FileInfo:
 
 class Point:
     """
-    坐标点\n
-    x: 横向坐标点\n
-    y: 纵向坐标点
+    坐标点。\n
+    :param x: 横向坐标点
+    :param y: 纵向坐标点
+    :ivar x: 横向坐标点
+    :ivar y: 纵向坐标点
     """
     x = int()
     y = int()
@@ -71,9 +73,9 @@ class Point:
 
 class LockState(enum.Enum):
     """
-    锁屏状态\n
-    LOCKED: 已锁定\n
-    UNLOCKED: 已解锁
+    锁屏状态。\n
+    :ivar LOCKED: 已锁定
+    :ivar UNLOCKED: 已解锁
     """
     LOCKED = 0
     UNLOCKED = 1
@@ -81,10 +83,10 @@ class LockState(enum.Enum):
 
 class DisplayState(enum.Enum):
     """
-    显示器状态\n
-    ON: 亮屏\n
-    OFF: 灭屏\n
-    DIM: 暗屏
+    显示器状态。\n
+    :ivar ON: 亮屏
+    :ivar OFF: 灭屏
+    :ivar DIM: 暗屏
     """
     ON = 0
     OFF = 1
@@ -93,12 +95,12 @@ class DisplayState(enum.Enum):
 
 class ScreenOrientation(enum.Enum):
     """
-    屏幕方向\n
-    PRIMARY: 主要方向 一般为0度\n
-    PORTRAIT: 纵向 一般为0度\n
-    LANDSCAPE: 横向 一般为90度\n
-    INVERTED_PORTRAIT: 反纵向 一般为180度\n
-    INVERTED_LANDSCAPE: 反横向 一般为270度
+    屏幕方向。\n
+    :ivar PRIMARY: 主要方向 一般为0度
+    :ivar PORTRAIT: 纵向 一般为0度
+    :ivar LANDSCAPE: 横向 一般为90度
+    :ivar INVERTED_PORTRAIT: 反纵向 一般为180度
+    :ivar INVERTED_LANDSCAPE: 反横向 一般为270度
     """
     PRIMARY = 0
     PORTRAIT = 1
@@ -109,13 +111,34 @@ class ScreenOrientation(enum.Enum):
 
 class Controller(enum.Enum):
     """
-    控制端类型\n
-    ANYWHERE: 非兼容平台\n
-    WINDOWS_AMD64: x86_64架构的windows平台，推荐windows10\n
-    LINUX_X86_64: x86_64架构的linux平台，推荐ubuntu18.04\n
-    DARWIN_X86_64: x86_64架构的macOSX平台，推荐Catalina
+    控制端类型。\n
+    :ivar ANYWHERE: 非兼容平台
+    :ivar WINDOWS_AMD64: x86_64架构的windows平台，推荐windows10
+    :ivar LINUX_X86_64: x86_64架构的linux平台，推荐ubuntu18.04
+    :ivar DARWIN_X86_64: x86_64架构的macOSX平台，推荐Catalina
     """
     ANYWHERE = 0
     WINDOWS_AMD64 = 1
     LINUX_X86_64 = 2
     DARWIN_X86_64 = 3
+
+
+class WatcherActive(enum.Enum):
+    """
+    Watcher执行动作类型。\n
+    :ivar CLICK: 点击屏幕
+    :ivar LAUNCH: 启动应用
+    """
+    CLICK = 0
+    LAUNCH = 1
+    PAUSE = 2
+
+
+class Keys(enum.Enum):
+    """
+    设备按键。\n
+    :ivar BACK: 返回按键
+    :ivar HOME: 主页按键
+    """
+    BACK = 0
+    HOME = 1
