@@ -306,7 +306,7 @@ class Device(Events):
         :param scale: 缩放系数
         :return: 截图的base64形态
         """
-        return str(self.con.get(path="grabImage?x=" + str(round(x))
+        return str(self.con.get(path="grabImage", args="x=" + str(round(x))
                               + "&y=" + str(round(y))
                               + "&w=" + str(round(width))
                               + "&h=" + str(round(height))
