@@ -15,13 +15,17 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import time
 import psutil
+from typing import TypeVar
+from .DataStruct import WatcherActive
+from .DataStruct import Keys
+
+WatchContext_T = TypeVar('WatchContext_T', bound='WatchContext')
 
 
 class WatchWorker:
-    
     watch_data = {}
     __watcher_list = []
-    
+
     def __init__(self, d, conn, main_pid):
         self.device = d
         self.conn = conn
@@ -49,13 +53,13 @@ class WatchWorker:
                     if flag == len(watcher['xpath_list']):
                         for xpath in watcher['xpath_list']:
                             if xpath['index'] == watcher['index']:
-                                if watcher['active'] == 'click':
+                                if watcher['active'] == WatcherActive.CLICK:
                                     self.device.find_item_by_xpath(xpath['sop_id'], xpath['xpath']).click()
-                                elif watcher['active'] == 'back':
+                                elif watcher['active'] == WatcherActive.PAUSE and watcher['active_key'] == Keys.BACK:
                                     self.device.back()
-                                elif watcher['active'] == 'home':
+                                elif watcher['active'] == WatcherActive.PAUSE and watcher['active_key'] == Keys.HOME:
                                     self.device.home()
-                                elif watcher['active'] == 'launch':
+                                elif watcher['active'] == WatcherActive.LAUNCH:
                                     self.device.launch(watcher['active_sop_id'], watcher['active_ui_app_id'])
             except Exception as e:
                 print(e)
@@ -65,14 +69,22 @@ class WatchWorker:
 
 
 class Watcher:
-
+    """
+    监视者类。
+    """
     __watcher_data = {}
 
     def __init__(self, data: dict, d):
         self.__watcher_data = data
         self.device = d
 
-    def when(self, sop_id: str, xpath_key: str):
+    def when(self, sop_id: str, xpath_key: str) -> WatchContext_T:
+        """
+        设置监视者判断条件。\n
+        :param sop_id: 设备应用sopid
+        :param xpath_key: 用于查询ini文件中xpath值的键
+        :return: 返回上下文WatchContext
+        """
         if 'xpath_list' not in self.__watcher_data.keys():
             self.__watcher_data['xpath_list'] = []
         index = len(self.__watcher_data['xpath_list'])
@@ -80,18 +92,27 @@ class Watcher:
                                                   'xpath': self.device.get_xpath(sop_id, xpath_key),
                                                   'sop_id': sop_id})
         self.__watcher_data['index'] = index
-        return _WatchContext(self.__watcher_data, self.device)
+        return WatchContext(self.__watcher_data, self.device)
 
 
-class _WatchContext:
-    
+class WatchContext:
+    """
+    监视者上下文类。
+    """
+
     __watcher_data = {}
-    
+
     def __init__(self, data: dict, d):
         self.__watcher_data = data
         self.device = d
 
-    def when(self, sop_id: str, xpath_key: str):
+    def when(self, sop_id: str, xpath_key: str) -> WatchContext_T:
+        """
+        设置监视者判断条件。\n
+        :param sop_id: 设备应用sopid
+        :param xpath_key: 用于查询ini文件中xpath值的键
+        :return: 返回上下文WatchContext
+        """
         if 'xpath_list' not in self.__watcher_data.keys():
             self.__watcher_data['xpath_list'] = []
         index = len(self.__watcher_data['xpath_list'])
@@ -102,21 +123,35 @@ class _WatchContext:
         return self
 
     def click(self) -> None:
-        self.__watcher_data['active'] = 'click'
+        """
+        如果所有when()接口设置的判断条件均为真时，执行点击操作，点击目标为最后一个when()设定的判断锚点控件。\n
+        :return: 无
+        """
+        self.__watcher_data['active'] = WatcherActive.CLICK
         self.__push()
 
-    def pause(self, key: str) -> None:
-        self.__watcher_data['active'] = key
+    def pause(self, key: Keys) -> None:
+        """
+        如果所有when()接口设置的判断条件均为真时，执行按键操作。\n
+        :param key: WatcherActive.Keys类型的枚举值，目前仅支持BACK和HOME
+        :return: 无
+        """
+        self.__watcher_data['active'] = WatcherActive.PAUSE
+        self.__watcher_data['active_key'] = key
         self.__push()
 
     def launch(self, sop_id: str, ui_app_id: str) -> None:
-        self.__watcher_data['active'] = 'launch'
+        """
+        如果所有when()接口设置的判断条件均为真时，执行启动APP操作。\n
+        :param sop_id: 要启动的设备应用sopid
+        :param ui_app_id: 要启动的设备应用uiappid
+        :return: 无
+        """
+        self.__watcher_data['active'] = WatcherActive.LAUNCH
         self.__watcher_data['active_sop_id'] = sop_id
         self.__watcher_data['active_ui_app_id'] = ui_app_id
         self.__push()
 
-    def __push(self) -> None:
+    def __push(self):
         self.device.watcher_list.append(self.__watcher_data)
         self.device.push_watcher_data()
-
-
